from typing import Optional

from sqlmodel import Session

from hogwarts_testing_platform.repo.base_repo import BaseRepo
from hogwarts_testing_platform.repo.fake_repo import FakeRepo
from hogwarts_testing_platform.repo.orm_repo import ORMRepo
from hogwarts_testing_platform.site.db import engine


class RepoFactory:
    @classmethod
    def get_repo(self, config: str, model):
        repo: Optional[BaseRepo] = None
        if config == 'orm':
            with Session(engine) as session:
                repo = ORMRepo(session, model)

        elif config == 'fake':
            repo = FakeRepo()
        else:
            raise Exception('unknown db')

        return repo
